@@ -1057,7 +1057,7 @@ or else connect to the server's desktop using a local X server like X2Go.
     proc = subprocess.Popen(command, shell=True, cwd=path)
     output, errors = proc.communicate()
     missing_r_dep = False
-    if proc.returncode != 0:
+    if proc.returncode != 0 and errors:
         errors = errors.decode("utf-8")
 
         # Check if it is Python dependency unsatisfied
